@@ -87,17 +87,17 @@ par.secr.fit <- function (arglist, ncores = 1, seed = NULL, trace = TRUE,
         output <- lapply(arglist, run.fit)
     }
     
-    ## apply standard naming convention
-    names(output) <- paste0(prefix, names(arglist))
-
     ## changed from memo() 2016-06-04
     message(paste('Completed in ', round((proc.time() - ptm)[3]/60,3), ' minutes at ',
         format(Sys.time(), "%H:%M:%S %d %b %Y"), sep=''))
 
     if (inherits(output[[1]], 'secr')) 
-        secrlist(output)
-    else 
-        output
+        output <- secrlist(output)
+
+    ## apply standard naming convention
+    names(output) <- paste0(prefix, names(arglist))
+
+    output
 }
 
 par.derived <- function (secrlist, ncores = 1, ...) {
